@@ -1,33 +1,23 @@
 /*
-  Copyright (C) 2013-2020 Laurent Montel <montel@kde.org>
+  SPDX-FileCopyrightText: 2013-2021 Laurent Montel <montel@kde.org>
 
-  This program is free software; you can redistribute it and/or modify it
-  under the terms of the GNU General Public License, version 2, as
-  published by the Free Software Foundation.
-
-  This program is distributed in the hope that it will be useful, but
-  WITHOUT ANY WARRANTY; without even the implied warranty of
-  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-  General Public License for more details.
-
-  You should have received a copy of the GNU General Public License along
-  with this program; if not, write to the Free Software Foundation, Inc.,
-  51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
+  SPDX-License-Identifier: GPL-2.0-only
 */
 
 #ifndef SIEVETREEWIDGETITEM_H
 #define SIEVETREEWIDGETITEM_H
 
+#include "ksieveui_export.h"
 #include <KPixmapSequence>
 #include <QTreeWidgetItem>
-
-#include "ksieveui_export.h"
+#include <memory>
 
 class QTimer;
 class QTreeWidget;
 class QTreeWidgetItem;
 
-namespace KSieveUi {
+namespace KSieveUi
+{
 class SieveTreeWidgetProgress;
 class SieveTreeWidgetItemPrivate;
 /**
@@ -38,7 +28,7 @@ class KSIEVEUI_EXPORT SieveTreeWidgetItem : public QTreeWidgetItem
 {
 public:
     SieveTreeWidgetItem(QTreeWidget *treeWidget, QTreeWidgetItem *item);
-    ~SieveTreeWidgetItem();
+    ~SieveTreeWidgetItem() override;
 
     void startAnimation();
     void stopAnimation();
@@ -46,7 +36,7 @@ public:
     void setProgressAnimation(const QPixmap &pix);
 
 private:
-    SieveTreeWidgetItemPrivate *const d;
+    std::unique_ptr<SieveTreeWidgetItemPrivate> const d;
 };
 
 class SieveTreeWidgetProgress : public QObject
@@ -54,7 +44,7 @@ class SieveTreeWidgetProgress : public QObject
     Q_OBJECT
 public:
     explicit SieveTreeWidgetProgress(SieveTreeWidgetItem *item, QObject *parent = nullptr);
-    ~SieveTreeWidgetProgress();
+    ~SieveTreeWidgetProgress() override;
 
     void startAnimation();
     void stopAnimation();
@@ -65,7 +55,7 @@ private:
     int mProgressCount = 0;
     KPixmapSequence mProgressPix;
     QTimer *mProgressTimer = nullptr;
-    SieveTreeWidgetItem *mItem = nullptr;
+    SieveTreeWidgetItem *const mItem;
 };
 }
 
